pub enum QueueItemState {
Authored,
Mirrored,
InProgress,
Answered,
Struck,
Reaped,
}Expand description
Lifecycle state of a single queue item, in ascending lawful order.
Variants
Implementations
Sourceimpl QueueItemState
impl QueueItemState
pub fn rank(self) -> u8
pub fn is_terminal(self) -> bool
Sourcepub fn lifecycle(self) -> QueueItemLifecycle
pub fn lifecycle(self) -> QueueItemLifecycle
Project this fine-grained lifecycle state onto the coarse rendered queue lattice the CRDT convergence joins over.